<?php 
/**
 * @package Wapple_Architect
 * @author Rich Gubby
 * @version 1.0.2
 */
/*
Plugin Name: Wapple Architect
Plugin URI: http://mobilewebjunkie.com/wordpress-mobile-plugin-install-guide-and-faq/
Description: Mobilizing your wordpress site using Wapple Architect and WAPL
Author: Rich Gubby
Version: 1.0.2
Author URI: http://mobilewebjunkie.com/
*/

/** 
 * Define some defaults - shouldn't need to change these
 */
// Width of images on the homepage
define('ARCHITECT_HOME_IMAGESCALE', 50);
// Quality of images on the homepage
define('ARCHITECT_HOME_IMAGEQUALITY', 95);
// Width of images on post pages
define('ARCHITECT_SINGLE_IMAGESCALE', 50);
// Quality of images on post pages
define('ARCHITECT_SINGLE_IMAGEQUALITY', 95);
// Width of images on designated pages
define('ARCHITECT_PAGE_IMAGESCALE', 50);
// Quality of images on designated pages
define('ARCHITECT_PAGE_IMAGEQUALITY', 95);
// Length of chars in post before a new page
define('ARCHITECT_SINGLE_PAGINGLENGTH', 2000);

/**
 * Debug purposes only - you shouldn't need to change these
 */ 
// Define whether a SOAP call is to be made - won't work without it!
define('ARCHITECT_DO_SOAP', true);
// Force the mobile check to always return true
define('ARCHITECT_FORCE_MOBILE', false);
// Turn a bit more debug on than is normal
define('ARCHITECT_DEBUG', false);

if(ARCHITECT_DEBUG)
{
	error_reporting(E_ALL);
	ini_set('display_errors', true);
}

if ( !defined('WP_CONTENT_DIR') )
	define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' ); // no trailing slash, full paths only - WP_CONTENT_URL is defined further down

if ( !defined('WP_PLUGIN_DIR') )
	define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' ); // full path, no trailing slash

if ( !defined('WP_CONTENT_URL') )
	define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content'); // full url - WP_CONTENT_DIR is defined further up
	
if ( !defined('WP_PLUGIN_URL') )
	define( 'WP_PLUGIN_URL', WP_CONTENT_URL . '/plugins' ); // full url, no trailing slash
	
/**
 * Main device detection kick off function
 * - Sets up a few global variables that we're going to use later and initiates a check for mobile.
 * - If the check for mobile comes back true, amend the path to the theme
 * @return void
 */
function deviceDetection()
{
	// Only do this if we're on a non-admin page (for now!)
	if(!is_admin())
	{
		// Setup a global SOAP client so we can use the same one in the theme
		global $waplSoapClient;
		// Setup global headers so we don't have to get them twice
		global $waplHeaders;
		
		// Create the SOAP client
		$waplSoapClient = __getSoapClient();
		// Get device / browser header information 
		$waplHeaders = __getHeaders();
		
		// If __testForMobile() comes back true, amend template path
		if(__testForMobile())
		{
			// Load the correct file depending on the URL (copied from template-loader.php)
			$template = __templateLoader();
			
			$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.$template;
			
			if(file_exists($file))
			{
				include($file);
				exit(0);
			}
		}
	}
}

/**
 * Work out which theme file to use
 * @return string
 */
function __templateLoader()
{
	if ( is_404()) {
		return '404.php';
	} else if ( is_search()) {
		return 'search.php';
	} else if ( is_home()) {
		return 'index.php';
	} else if ( is_single()) {
		return 'single.php';
	} else if ( is_page()) {
		return 'page.php';
	} else if ( is_archive()) {
		return 'archive.php';
	} else if (file_exists(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'index.php' )) {
		return 'index.php';
	}
}

/**
 * Perform a device detection check
 * @return boolean
 */
function __testForMobile()
{
	global $waplSoapClient;
	global $waplHeaders;
	
	// If we've defined ARCHITECT_DO_SOAP, just return the value of ARCHITECT_FORCE_MOBILE
	if(!ARCHITECT_DO_SOAP)
	{
		return ARCHITECT_FORCE_MOBILE;
	}
	
	if(!get_option('architect_devkey'))
	{
		return false;
	}
	
	// Check for existence of a cookie
	if(isset($_COOKIE['isMobile']))
	{
		return $_COOKIE['isMobile'];
	} else
	{
		// Test for mobile
		$params = array(
			'devKey' => get_option('architect_devkey'),
			'deviceHeaders' => $waplHeaders
		);

		if(!is_object($waplSoapClient))
		{
			// We don't have a SOAP client
			return false;
		}
		$result = $waplSoapClient->isMobileDevice($params);
		if(is_soap_fault($result))
		{
			// There is a SOAP error! probably a dev key error
			return false;
		}  else
		{
			if($result)
			{
				// Set a cookie to remember the outcome!
				setcookie('isMobile', true, time()+3600);
				return true;
			} else
			{
				setcookie('isMobile', false, time()+3600);
				return false;
			}
		}
	}
}

/**
 * Get a SOAP client
 * @return mixed
 */
function __getSoapClient()
{
	if(ARCHITECT_DO_SOAP)
	{
		return new SoapClient('http://webservices.wapple.net/wapl.wsdl', array('exceptions' => 0));
	} else
	{
		return false;
	}	
}

/**
 * Build device header array that SOAP can use
 * @return array
 */
function __getHeaders()
{
	$headers = array();
	foreach($_SERVER as $key => $val)
	{
		$headers[] = array('name' => $key, 'value' => $val);
	}
	return $headers;
}

// Add the deviceDetection function to the template_redirect filter
add_action('template_redirect', 'deviceDetection');
// Add architect options to admin menu
add_action('admin_menu', 'add_architect_options_page');

/**
 * Add architect admin options
 * @return void
 */
function add_architect_options_page()
{
	add_options_page('Wapple Architect Settings', 'Wapple Architect', 8, basename(__FILE__), 'architect_options_page');
}

/**
 * Display architect options and save when requested
 * @return void
 */
function architect_options_page()
{
	echo '<div class="wrap">';
	
	if (isset($_POST['info_update'])) 
	{
		$updateOption = false;
		if($_POST['architect_devkey'] != get_option('architect_devkey'))
		{
			update_option('architect_devkey', $_POST['architect_devkey']);
			$updateOption = true;
		}
		if($_POST['architect_use_headerimage'] != get_option('architect_use_headerimage'))
		{
			update_option('architect_use_headerimage', $_POST['architect_use_headerimage']);
			$updateOption = true;
		}
		if(isset($_FILES['architect_headerimage']))
		{
			$pathToHeader = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'header'.DIRECTORY_SEPARATOR;
			if(move_uploaded_file($_FILES['architect_headerimage']['tmp_name'], $pathToHeader.$_FILES['architect_headerimage']['name']))
			{
				update_option('architect_headerimage', $_FILES['architect_headerimage']['name']);
				$updateOption = true;
			}
		}
		if($_POST['architect_use_footerimage'] != get_option('architect_use_footerimage'))
		{
			update_option('architect_use_footerimage', $_POST['architect_use_footerimage']);
			$updateOption = true;
		}
		if(isset($_FILES['architect_footerimage']))
		{
			$pathToFooter = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'footer'.DIRECTORY_SEPARATOR;
			
			if(move_uploaded_file($_FILES['architect_footerimage']['tmp_name'], $pathToFooter.$_FILES['architect_footerimage']['name']))
			{
				update_option('architect_footerimage', $_FILES['architect_footerimage']['name']);
				$updateOption = true;
			}
		}
		if($_POST['architect_showmenuatbottom'] != get_option('architect_showmenuatbottom'))
		{
			update_option('architect_showmenuatbottom', $_POST['architect_showmenuatbottom']);
			$updateOption = true;
		}
		if($_POST['architect_home_showexcerpt'] != get_option('architect_home_showexcerpt'))
		{
			update_option('architect_home_showexcerpt', $_POST['architect_home_showexcerpt']);
			$updateOption = true;
		}
		if($_POST['architect_home_imagescale'] != get_option('architect_home_imagescale'))
		{
			update_option('architect_home_imagescale', $_POST['architect_home_imagescale']);
			$updateOption = true;
		}
		if($_POST['architect_home_imagequality'] != get_option('architect_home_imagequality'))
		{
			update_option('architect_home_imagequality', $_POST['architect_home_imagequality']);
			$updateOption = true;
		}
		if($_POST['architect_single_dopaging'] != get_option('architect_single_dopaging'))
		{
			update_option('architect_single_dopaging', $_POST['architect_single_dopaging']);
			$updateOption = true;
		}
		if($_POST['architect_single_paginglength'] != get_option('architect_single_paginglength'))
		{
			update_option('architect_single_paginglength', $_POST['architect_single_paginglength']);
			$updateOption = true;
		}
		if($_POST['architect_single_shownext'] != get_option('architect_single_shownext'))
		{
			update_option('architect_single_shownext', $_POST['architect_single_shownext']);
			$updateOption = true;
		}
		if($_POST['architect_single_imagescale'] != get_option('architect_single_imagescale'))
		{
			update_option('architect_single_imagescale', $_POST['architect_single_imagescale']);
			$updateOption = true;
		}
		if($_POST['architect_single_imagequality'] != get_option('architect_single_imagequality'))
		{
			update_option('architect_single_imagequality', $_POST['architect_single_imagequality']);
			$updateOption = true;
		}
		if($_POST['architect_single_responseformat'] != get_option('architect_single_responseformat'))
		{
			update_option('architect_single_responseformat', $_POST['architect_single_responseformat']);
			$updateOption = true;
		}
		if($_POST['architect_page_imagescale'] != get_option('architect_page_imagescale'))
		{
			update_option('architect_page_imagescale', $_POST['architect_page_imagescale']);
			$updateOption = true;
		}
		if($_POST['architect_page_imagequality'] != get_option('architect_page_imagequality'))
		{
			update_option('architect_page_imagequality', $_POST['architect_page_imagequality']);
			$updateOption = true;
		}
		if($_POST['architect_home_showsearch'] != get_option('architect_home_showsearch'))
		{
			update_option('architect_home_showsearch', $_POST['architect_home_showsearch']);
			$updateOption = true;
		}
		if($_POST['architect_search_showtags'] != get_option('architect_search_showtags'))
		{
			update_option('architect_search_showtags', $_POST['architect_search_showtags']);
			$updateOption = true;
		}
		if($_POST['architect_search_showcategories'] != get_option('architect_search_showcategories'))
		{
			update_option('architect_search_showcategories', $_POST['architect_search_showcategories']);
			$updateOption = true;
		}
		
		$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'style.css';
		$stylesheet = file_get_contents($file);
		
		if(stripslashes($_POST['architect_stylesheet']) != $stylesheet)
		{
			if(file_put_contents($file, stripslashes($_POST['architect_stylesheet'])))
			{
				$updateOption = true;
			}
		}
		
		if($updateOption)
		{
			echo "<div class='updated fade'><p><strong>Wapple Architect settings saved.</strong></p></div>";
		}
	}
	echo '
		<form method="post" action="options-general.php?page=architect.php" enctype="multipart/form-data">
			<h2>Wapple Architect Settings</h2>
			
		<p><em>
			Wapple Architect WordPress plugin is brought to you by Rich Gubby - <a href="http://mobilewebjunkie.com">http://mobilewebjunkie.com</a>
		</em></p>
		
		<h3>Basic Settings</h3>
		
		<table class="form-table" cellspacing="2" cellpadding="5" width="100%">
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_devkey">Wapple Architect Dev Key:</label>
				</th>
				<td>
					<input size="40" type="text" name="architect_devkey" id="architect_devkey" value="'.get_option('architect_devkey').'" />
				</td>
			</tr>
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_use_headerimage">Use mobile header image:</label>
				</th>
				<td>
					<select name="architect_use_headerimage">';
	if(get_option('architect_use_headerimage') == '1')
	{
		echo '<option value="1" selected="selected">Yes</option><option value="0">No</option>';
	} else
	{
		echo '<option value="1">Yes</option><option value="0" selected="selected">No</option>';
	}
	
	echo '</select>
				</td>
			</tr>
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_headerimage">Mobile site header image:</label>
				</th>
				<td><input type="file" name="architect_headerimage" id="architect_headerimage" /></td>
			</tr>';
	
	if(get_option('architect_headerimage'))
	{
		echo '
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_headerimage">Mobile site header image preview:</label>
				</th>
				<td><img src="/wp-content/plugins/'.get_wapl_plugin_base().'/theme/images/header/'.get_option('architect_headerimage').'" alt="Mobile Header Image" /> 
				</td>
			</tr>';
	}
	
	echo '
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_use_footerimage">Use mobile footer image:</label>
				</th>
				<td>
					<select name="architect_use_footerimage">';
	if(get_option('architect_use_footerimage') == '1')
	{
		echo '<option value="1" selected="selected">Yes</option><option value="0">No</option>';
	} else
	{
		echo '<option value="1">Yes</option><option value="0" selected="selected">No</option>';
	}
	
	echo '</select>
				</td>
			</tr>
			
		<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_footerimage">Mobile site footer image:</label>
				</th>
				<td><input type="file" name="architect_footerimage" id="architect_footerimage" /></td>
			</tr>';
	
	if(get_option('architect_footerimage'))
	{
		echo '
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_headerimage">Mobile site footer image preview:</label>
				</th>
				<td><img src="/wp-content/plugins/'.get_wapl_plugin_base().'/theme/images/footer/'.get_option('architect_footerimage').'" alt="Mobile Footer Image" /> 
				</td>
			</tr>';
	}
	echo '
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_showmenuatbottom">Show menu at bottom:</label>
				</th>
				<td>
					<select name="architect_showmenuatbottom">';
	if(get_option('architect_showmenuatbottom') == '1')
	{
		echo '<option value="1" selected="selected">Yes</option><option value="0">No</option>';
	} else
	{
		echo '<option value="1">Yes</option><option value="0" selected="selected">No</option>';
	}
	
	echo '</select>
				</td>
			</tr>
	</table>
		
		<h3>Home page Settings</h3>
		
		<table class="form-table" cellspacing="2" cellpadding="5" width="100%">
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_home_showexcerpt">Show excerpt on homepage:</label>
				</th>
				<td>
					<select name="architect_home_showexcerpt">';
	if(get_option('architect_home_showexcerpt') == '1')
	{
		echo '<option value="1" selected="selected">Yes</option><option value="0">No</option>';
	} else
	{
		echo '<option value="1">Yes</option><option value="0" selected="selected">No</option>';
	}
	
	echo '</select>
				</td>
			</tr>
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_home_imagescale">Image scale on homepage:</label>
				</th>
				<td>';
	$homepagescale = ARCHITECT_HOME_IMAGESCALE;
	if(get_option('architect_home_imagescale'))
	{
		$homepagescale = get_option('architect_home_imagescale');
	}
	echo '
					<input size="2" type="text" name="architect_home_imagescale" id="architect_home_imagescale" value="'.$homepagescale.'" />%
				</td>
			</tr>
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_home_imagequality">Image quality on homepage:</label>
				</th>
				<td>';
	$homepagequality = ARCHITECT_HOME_IMAGEQUALITY;
	if(get_option('architect_home_imagequality'))
	{
		$homepagequality = get_option('architect_home_imagequality');
	}
	echo '
					<input size="2" type="text" name="architect_home_imagequality" id="architect_home_imagequality" value="'.$homepagequality.'" />%
				</td>
			</tr>
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_home_showsearch">Show search on home page:</label>
				</th>
				<td>
					<select name="architect_home_showsearch">';
	if(get_option('architect_home_showsearch') == '1')
	{
		echo '<option value="1" selected="selected">Yes</option><option value="0">No</option>';
	} else
	{
		echo '<option value="1">Yes</option><option value="0" selected="selected">No</option>';
	}
	
	echo '</select>
				</td>
			</tr>
		</table>
		
		<h3>Posts Settings</h3>
		
		<table class="form-table" cellspacing="2" cellpadding="5" width="100%">
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_single_dopaging">Do pagination:</label>
				</th>
				<td>
					<select name="architect_single_dopaging">';
	if(get_option('architect_single_dopaging') == '1')
	{
		echo '<option value="1" selected="selected">Yes</option><option value="0">No</option>';
	} else
	{
		echo '<option value="1">Yes</option><option value="0" selected="selected">No</option>';
	}
	
	echo '</select>
				</td>
			</tr>
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_single_paginglength">Post length:</label>
				</th>
				<td>';
	if(get_option('architect_single_paginglength'))
	{
		$singlepagepaginglength = get_option('architect_single_paginglength');
	} else
	{
		$singlepagepaginglength = ARCHITECT_SINGLE_PAGINGLENGTH; 
	}
	echo '
					<input size="4" type="text" name="architect_single_paginglength" id="architect_single_paginglength" value="'.$singlepagepaginglength.'" />chars
				</td>
			</tr>
			
			
		
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_single_shownext">Show next/previous links:</label>
				</th>
				<td>
					<select name="architect_single_shownext">';
	if(get_option('architect_single_shownext') == '1')
	{
		echo '<option value="1" selected="selected">Yes</option><option value="0">No</option>';
	} else
	{
		echo '<option value="1">Yes</option><option value="0" selected="selected">No</option>';
	}
	
	echo '</select>
				</td>
			</tr>
		
		
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_single_imagescale">Image scale on post:</label>
				</th>
				<td>';
	$singlepagescale = ARCHITECT_SINGLE_IMAGESCALE;
	if(get_option('architect_single_imagescale'))
	{
		$singlepagescale = get_option('architect_single_imagescale');
	}
	echo '
					<input size="2" type="text" name="architect_single_imagescale" id="architect_single_imagescale" value="'.$singlepagescale.'" />%
				</td>
			</tr>
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_single_imagequality">Image quality on post:</label>
				</th>
				<td>';
	$singlepagequality = ARCHITECT_SINGLE_IMAGEQUALITY;
	if(get_option('architect_single_imagequality'))
	{
		$singlepagequality = get_option('architect_single_imagequality');
	}
	echo '
					<input size="2" type="text" name="architect_single_imagequality" id="architect_single_imagequality" value="'.$singlepagequality.'" />%
				</td>
			</tr>
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_single_responseformat"># responses text:</label>
				</th>
				<td>
	<select name="architect_single_responseformat">';
	
	$options = array(
		'1' => '1 response',
		'2' => '1 response to [post title]',
		'3' => '1 comment',
		'4' => '1 comment to [post title]',
	);
	$architect_single_responseformat = get_option('architect_single_responseformat');
	foreach($options as $key => $val)
	{
		echo '<option value="'.$key.'"';
		if($key == $architect_single_responseformat)
		{
			echo ' selected="selected"';
		}
		echo '>'.$val.'</option>';
	}
	
	echo '</select>
				</td>
			</tr>
		</table>
		
		<h3>Pages Settings</h3>

		<table class="form-table" cellspacing="2" cellpadding="5" width="100%">
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_home_imagescale">Image scale on page:</label>
				</th>
				<td>';
	$pagescale = ARCHITECT_PAGE_IMAGESCALE;
	if(get_option('architect_page_imagescale'))
	{
		$pagescale = get_option('architect_page_imagescale');
	}
	echo '
					<input size="2" type="text" name="architect_page_imagescale" id="architect_page_imagescale" value="'.$pagescale.'" />%
				</td>
			</tr>
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_home_imagequality">Image quality on page:</label>
				</th>
				<td>';
	$pagequality = ARCHITECT_PAGE_IMAGEQUALITY;
	if(get_option('architect_page_imagequality'))
	{
		$pagequality = get_option('architect_page_imagequality');
	}
	echo '
					<input size="2" type="text" name="architect_page_imagequality" id="architect_page_imagequality" value="'.$pagequality.'" />%
				</td>
			</tr>
			
		</table>

		<h3>Search Results Settings</h3>
		
		<table class="form-table" cellspacing="2" cellpadding="5" width="100%">
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_search_showtags">Show tags on search results:</label>
				</th>
				<td>
					<select name="architect_search_showtags">';
	if(get_option('architect_search_showtags') == '1')
	{
		echo '<option value="1" selected="selected">Yes</option><option value="0">No</option>';
	} else
	{
		echo '<option value="1">Yes</option><option value="0" selected="selected">No</option>';
	}
	
	echo '</select>
				</td>
			</tr>
			<tr>
				<th width="30%" valign="top" style="padding-top: 10px;">
					<label for="architect_search_showcategories">Show categories on search results:</label>
				</th>
				<td>
					<select name="architect_search_showcategories">';
	if(get_option('architect_search_showcategories') == '1')
	{
		echo '<option value="1" selected="selected">Yes</option><option value="0">No</option>';
	} else
	{
		echo '<option value="1">Yes</option><option value="0" selected="selected">No</option>';
	}
	
	echo '</select>
				</td>
			</tr>
		</table>
		
		<h3>Mobile Theme Settings</h3>
		
		<table class="form-table" cellspacing="2" cellpadding="5" width="100%">
			<tr>
				
				<td>
					<strong>Mobile stylesheet</strong><br />';
	$stylesheet = file_get_contents(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'style.css');
					
	echo '<textarea id="architect_stylesheet" name="architect_stylesheet" rows="25" cols="70">'.$stylesheet.'</textarea>
				</td>
			</tr>
		</table>
		
		<table class="form-table" cellspacing="2" cellpadding="5" width="100%">
			<tr>
				<td>
					<p class="submit">
						<input class="button-primary" type="submit" name="info_update" value="Save Changes" />
					</p>
				</td>
			</tr>
		</table>
		</form>
	</div>';
}

function architect_add_headerimage()
{
	echo '<input type="file" name="architect_add_headerimage" id="architect_add_headerimage" />';
}

if(!function_exists('get_wapl_plugin_base'))
{
	function get_wapl_plugin_base()
	{
		$base = plugin_basename(__FILE__);
		$baseExplode = explode(DIRECTORY_SEPARATOR, $base);
		return $baseExplode[0];
	}
}

?>